//
//  TestVideoViewController.m
//  PokktManager
//
//  Created by Pokkt on 3/2/15.
//  Copyright (c) 2015 Pokkt. All rights reserved.
//

#import "TestVideoViewController.h"
#import "AppDelegate.h"
#import "PokktManager.h"
#import "PokktController.h"
#import "VideoResponse.h"
#import "PokktConfig.h"

#define ErnedPoints @"Points"
#define userDefaluts [NSUserDefaults standardUserDefaults]

@interface TestVideoViewController ()<PokktDelegate>
@property (nonatomic, strong) AppDelegate *appdelegate;

@property (nonatomic, strong) PokktConfig *pokktConfig;
@property (nonatomic) float point;

@end

@implementation TestVideoViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    
    self.appdelegate = [UIApplication sharedApplication].delegate;
    self.pokktConfig  = [[PokktConfig alloc]init];
    [PokktManager setDebug: YES];
    

    self.pokktConfig.applicationId = @"a2717a45b835b5e9f50284a38d62a74e";
    self.pokktConfig.securityKey = @"iJ02lJss0M";
    self.pokktConfig.thirdPartyUserId = @"123456";
    self.pokktConfig.screenName = @"default";
    self.pokktConfig.name = @"ramesh";
    self.pokktConfig.age = @"27";
    self.pokktConfig.emailAddress = @"ramesh@gmail.com";
    self.pokktConfig.autoCacheVideo = YES;
    self.pokktConfig.incentivised = YES;
    self.pokktConfig.skipEnabled = YES;
    self.pokktConfig.defaultSkipTime = 10;
    
    [PokktManager startSession:self.pokktConfig];
    
    [PokktManager initPokkt:self.pokktConfig];
    [PokktManager setPokktDelegate:self];
    [PokktManager setPresentView:self];

    [self updatepointsEarned];
   
}


-(void)viewWillAppear:(BOOL)animated{
    [super viewWillAppear:animated];
    if ([PokktManager isVideoAvailable]) {
        [self showButton:YES];
    }else{
        [self showButton:NO];
    }
    [self.navigationController setNavigationBarHidden:YES];   //it hides
}

-(void)viewWillDisappear:(BOOL)animated{
    [super viewWillDisappear:animated];
    [self.navigationController setNavigationBarHidden:NO];    // it shows
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark - Button Action

- (IBAction)plaVdoButtonActions:(UIButton *)sender {
    
    if (sender.tag == 1)
    {
        self.pokktConfig.incentivised = YES;
        [PokktManager playVideoCampaign:self.pokktConfig];
    }
    else if (sender.tag == 2)
    {
        self.pokktConfig.incentivised = NO;
        [PokktManager playVideoCampaign:self.pokktConfig];
    }
    else if(sender.tag == 3)
    {
        if (![PokktManager isVideoAvailable])
        {
            [self performSegueWithIdentifier:@"StaticPage" sender:self];
        }
        else
        {
            self.pokktConfig.incentivised = NO;
            [PokktManager playVideoCampaign:self.pokktConfig];
        }
    }
    else
    {
        [PokktManager exportPokktSDKLog];
    }
}

#pragma mark - Private Methods

- (void)updatepointsEarned {
    if([userDefaluts objectForKey:ErnedPoints]) {
        self.point = [[userDefaluts objectForKey:ErnedPoints] intValue];
        self.pointsCountLbl.text = [NSString stringWithFormat:@"Points earned : %.2f",self.point];
    }
}

- (void)showButton:(BOOL)show {
    self.playIncentVdoBtn.hidden = !show;
    self.playNonIncentVdoBtn.hidden = !show;
}

- (void)showAlertWithMessage:(NSString *)msg {
    UIAlertView *alert = [[UIAlertView alloc]initWithTitle:@"" message:msg delegate:nil cancelButtonTitle:@"OK" otherButtonTitles:nil];
    [alert show];
}

#pragma mark - Pokkt Delegates

- (void)didFinishedVideoDownload:(BOOL)isFinished {
    [self.playIncentVdoBtn setTitle:[NSString stringWithFormat:@"Play Incent Vdo To Earn %.2f",[PokktManager getVideoVc]] forState:UIControlStateNormal];
    [self showButton:YES];
}

- (void)didFailedVideoDownload:(NSString *)error {
    [self showButton:NO];
}

- (void)onVideoClosed:(BOOL)isClosed {
    [self performSelector:@selector(showAlertWithMessage:) withObject:@"Video is closed" afterDelay:0.1];
//    [self showAlertWithMessage:@"Video is closed"];
}

- (void)onVideoCompleated:(BOOL)isCompleated {
    [self performSelector:@selector(showAlertWithMessage:) withObject:@"Video is compleated" afterDelay:0.1];

//    [self showAlertWithMessage:@"Video is compleated"];
}

- (void)onVideoDisplayed  {
    [self performSelector:@selector(showAlertWithMessage:) withObject:@"Video is displayed" afterDelay:0.1];

//    [self showAlertWithMessage:@"Video is displayed"];
}

- (void)onVideoGratified:(VideoResponse *)videoResponse {
    if([userDefaluts objectForKey:ErnedPoints]) {
        self.point = [[userDefaluts objectForKey:ErnedPoints] floatValue];
    }
    if (videoResponse.coins) {
        self.point += [videoResponse.coins floatValue];
        [userDefaluts setValue:[NSString stringWithFormat:@"%.2f",self.point] forKey:ErnedPoints];
        [userDefaluts synchronize];
        [self updatepointsEarned];
    }
}

- (void)onVideoSkiped {
    [self performSelector:@selector(showAlertWithMessage:) withObject:@"Video is skipped" afterDelay:0.1];
//    [self showAlertWithMessage:@"Video is skipped"];
}

- (void)onVideoClosed {
    [self performSelector:@selector(showAlertWithMessage:) withObject:@"Video is closed" afterDelay:0.1];
//    [self showAlertWithMessage:@"Video is closed"];

}

#pragma mark - Orienation

- (UIInterfaceOrientationMask)supportedInterfaceOrientations
{
    if (self.appdelegate.deviceType == iPhone4s || self.appdelegate.deviceType == iPhone5 || self.appdelegate.deviceType == iPhone5s) {
        return UIInterfaceOrientationMaskPortrait;
    }
    return UIInterfaceOrientationMaskAll;
}

@end
