//
//  AppDelegate.swift
//  SwiftSample
//
//  Created by SWARAJ on 24/04/15.
//  Copyright (c) 2015 Pokkt. All rights reserved.
//

import UIKit

enum DeviceType {
    case iPhone4s, iPhone5, iPhone5s, iPhone6, iPhone6Plus, iPad
}

@UIApplicationMain
class AppDelegate: UIResponder, UIApplicationDelegate {

    var window: UIWindow?
    
    var deviceType : DeviceType = DeviceType.iPad;
    
    let _SYS_NAMELEN = 256;
    
    func machineName() -> NSString {
        // Declare an array that can hold the bytes required to store `utsname`, initilized
        // with zeros. We do this to get a chunk of memory that is freed upon return of
        // the method
        var sysInfo: [CChar] = Array(count: sizeof(utsname), repeatedValue: 0)
        
        // We need to get to the underlying memory of the array:
        let machine = sysInfo.withUnsafeMutableBufferPointer { (inout ptr: UnsafeMutableBufferPointer<CChar>) -> String in
            // Call uname and let it write into the memory Swift allocated for the array
            uname(UnsafeMutablePointer<utsname>(ptr.baseAddress))
            
            // Now here is the ugly part: `machine` is the 5th member of `utsname` and
            // each member member is `_SYS_NAMELEN` sized. We skip the the first 4 members
            // of the struct which will land us at the memory address of the `machine` member
            let machinePtr = ptr.baseAddress.advancedBy(Int(_SYS_NAMELEN * 4))
            
            // Create a Swift string from the C string
            return String.fromCString(machinePtr)!
        }
        
        return machine;
    }
    
    func checkDeviceType(){
        switch machineName()
        {
            case "iPhone4,1": deviceType = DeviceType.iPhone4s;
            case "iPhone5,1": deviceType = DeviceType.iPhone5;
            case "iPhone5,2": deviceType = DeviceType.iPhone5;
            case "iPhone5,3": deviceType = DeviceType.iPhone5;
            case "iPhone5,4": deviceType = DeviceType.iPhone5;
            case "iPhone6,1": deviceType = DeviceType.iPhone5;
            case "iPhone6,2": deviceType = DeviceType.iPhone5;
            case "iPhone7,1": deviceType = DeviceType.iPhone6;
            case "iPhone7,2": deviceType = DeviceType.iPhone6Plus;
            default: deviceType = DeviceType.iPad;
        }
    }


    func application(application: UIApplication, didFinishLaunchingWithOptions launchOptions: [NSObject: AnyObject]?) -> Bool {
        // Override point for customization after application launch.
        checkDeviceType()
        return true
    }

    func applicationWillResignActive(application: UIApplication) {
        // Sent when the application is about to move from active to inactive state. This can occur for certain types of temporary interruptions (such as an incoming phone call or SMS message) or when the user quits the application and it begins the transition to the background state.
        // Use this method to pause ongoing tasks, disable timers, and throttle down OpenGL ES frame rates. Games should use this method to pause the game.
    }

    func applicationDidEnterBackground(application: UIApplication) {
        // Use this method to release shared resources, save user data, invalidate timers, and store enough application state information to restore your application to its current state in case it is terminated later.
        // If your application supports background execution, this method is called instead of applicationWillTerminate: when the user quits.
    }

    func applicationWillEnterForeground(application: UIApplication) {
        // Called as part of the transition from the background to the inactive state; here you can undo many of the changes made on entering the background.
    }

    func applicationDidBecomeActive(application: UIApplication) {
        // Restart any tasks that were paused (or not yet started) while the application was inactive. If the application was previously in the background, optionally refresh the user interface.
    }

    func applicationWillTerminate(application: UIApplication) {
        // Called when the application is about to terminate. Save data if appropriate. See also applicationDidEnterBackground:.
    }

}