//
//  TestVideoViewController.swift
//  SwiftSample
//
//  Created by SWARAJ on 24/04/15.
//  Copyright (c) 2015 Pokkt. All rights reserved.
//

import Foundation
import UIKit


class TestVideoViewController: UIViewController,PokktDelegate {
    
    let appDelegate = UIApplication.sharedApplication().delegate as! AppDelegate;
    
    var point : Float = 0
    
    let notificationCenter = NSNotificationCenter.defaultCenter()
    
    let defaults = NSUserDefaults.standardUserDefaults()
    
    let ErnedPoints = "Points"
    
    @IBOutlet weak var pointsCountLbl: UILabel?
    
    @IBOutlet weak var playIncentVdoBtn: UIButton?
    
    @IBOutlet weak var playNonIncentVdoBtn : UIButton?
    
    @IBOutlet weak var userWithOutIncentVdoBtn : UIButton?
    
    let pokktConfig:PokktConfig = PokktConfig()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        pokktConfig.applicationId = "a2717a45b835b5e9f50284a38d62a74e"
        pokktConfig.securityKey = "iJ02lJss0M"
        pokktConfig.autoCacheVideo = true
        pokktConfig.skipEnabled = true
        pokktConfig.defaultSkipTime = 10
        
        PokktManager.setDebug(true)
        
        PokktManager.startSession(pokktConfig)
        
        PokktManager.initPokkt(pokktConfig)
        
        PokktManager.setPresentView(self)
        PokktManager.setPokktDelegate(self)
        
        updatepointsEarned()
        
        notificationCenter.addObserver(
            self,
            selector: "playVideo",
            name:UIApplicationDidBecomeActiveNotification,
            object: nil
        )
        // Do any additional setup after loading the view, typically from a nib.
    }
    
    func playVideo() {
        notificationCenter.postNotificationName("app", object:nil)
    }
    
    override func viewWillAppear(animated:Bool){
        super.viewWillAppear(animated)
        showButton(false)
        self.navigationController?.setNavigationBarHidden(true,animated:false)
    }
    
    override func viewWillDisappear(animated:Bool){
        super.viewWillDisappear(animated)
        self.navigationController?.setNavigationBarHidden(false,animated:false)
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    @IBAction func plaVdoButtonActions(sender:UIButton) {
    
        if (sender.tag == 1)
        {
            PokktManager.playVideoCampaign(pokktConfig)
        }
        else if (sender.tag == 2)
        {
            PokktManager.playVideoCampaign(pokktConfig)
        }
        else if(sender.tag == 3)
        {
            let isVideoAvailable:Bool = PokktManager.isVideoAvailable();
            if (isVideoAvailable)
            {
                PokktManager.playVideoCampaign(pokktConfig)
            }
            else
            {
                performSegueWithIdentifier("StaticPage",sender:self)
            }
        }
        else
        {
            PokktManager.exportPokktSDKLog();
        }
    }
    
    func updatepointsEarned() {
        if(defaults.objectForKey(ErnedPoints) != nil){
            point = defaults.objectForKey(ErnedPoints)!.floatValue
            pointsCountLbl!.text = String(format:"Points earned : %.2f",self.point)
        }
    }
    
    func showButton(show:Bool) {
        self.playIncentVdoBtn!.hidden = !show;
        self.playNonIncentVdoBtn!.hidden = !show;
    }
    
    func showAlertWithMessage(msg:String) {
        let alert:UIAlertView = UIAlertView(title:"",message:msg,delegate:nil,cancelButtonTitle:"OK");
        alert.show()
    }
    
    func didFinishedVideoDownload(isFinished:Bool){
        playIncentVdoBtn?.setTitle(String(format:"Play Incent Vdo To Earn %.2f",PokktManager.getVideoVc()), forState:UIControlState.Normal)
        showButton(true)
    }
    
    func didFailedVideoDownload(errorMsg:String){
        showButton(false)
    }
    
    func onVideoCompleated(isCompleated:Bool){
        let time = dispatch_time(DISPATCH_TIME_NOW, Int64(0.1))
        dispatch_after(time, dispatch_get_main_queue(), {
            NSThread.detachNewThreadSelector(Selector("showAlertWithMessage:"), toTarget:self, withObject:"Video is completed")
        })
    }
    
    func onVideoDisplayed(){
        let time = dispatch_time(DISPATCH_TIME_NOW, Int64(0.1))
        dispatch_after(time, dispatch_get_main_queue(), {
            NSThread.detachNewThreadSelector(Selector("showAlertWithMessage:"), toTarget:self, withObject:"Video is displayed")
        })
    }
    
    func onVideoGratified(videoResponse:VideoResponse){
        if(defaults.objectForKey(ErnedPoints) != nil){
            point = defaults.objectForKey(ErnedPoints)!.floatValue
        }
        if(!videoResponse.coins.isEmpty){
            point += (videoResponse.coins as NSString).floatValue
            defaults.setValue(String(format:"%.2f",self.point), forKey: ErnedPoints)
            defaults.synchronize()
            updatepointsEarned()
        }
    }
    
    func onVideoSkiped(){
        let time = dispatch_time(DISPATCH_TIME_NOW, Int64(0.1))
        dispatch_after(time, dispatch_get_main_queue(), {
            NSThread.detachNewThreadSelector(Selector("showAlertWithMessage:"), toTarget:self, withObject:"Video is skipped")
        })
    }
    
    func onVideoClosed(){
        let time = dispatch_time(DISPATCH_TIME_NOW, Int64(0.1))
        dispatch_after(time, dispatch_get_main_queue(), {
            NSThread.detachNewThreadSelector(Selector("showAlertWithMessage:"), toTarget:self, withObject:"Video is closed")
        })
    }
    
    override func supportedInterfaceOrientations() -> UIInterfaceOrientationMask {
        if(self.appDelegate.deviceType == DeviceType.iPhone4s || self.appDelegate.deviceType == DeviceType.iPhone5 || self.appDelegate.deviceType == DeviceType.iPhone5s){
            return UIInterfaceOrientationMask.Portrait
        }
        return UIInterfaceOrientationMask.All
    }
    
}